@@ -1,21 +1,21 @@
 import argparse
 import sys
 
-from . import __version__, displays, extractors
+from . import __version__, displays, parsers
 
 
 def main():
-    parser = argparse.ArgumentParser(
+    arg_parser = argparse.ArgumentParser(
         description="Hotkey aggregator. All your hotkeys in one place."
     )
 
-    group = parser.add_mutually_exclusive_group()
+    group = arg_parser.add_mutually_exclusive_group()
     group.add_argument(
-        "-le",
-        "--list-extractors",
-        help="List available hotkey extractors.",
+        "-lp",
+        "--list-parsers",
+        help="List available hotkey parsers.",
         action="store_true",
-        dest="list_extractors",
+        dest="list_parsers",
     )
     group.add_argument(
         "-ld",
@@ -24,60 +24,61 @@ def main():
         action="store_true",
         dest="list_displays",
     )
-    parser.add_argument(
-        "extractor",
+    arg_parser.add_argument(
+        "parser",
         nargs="?",
-        help="Extract hotkeys using extractor.",
-        choices=[i.lower() for i in extractors.__all__],
+        help="Extract hotkeys using parser.",
+        choices=[i.lower() for i in parsers.__all__],
     )
-    parser.add_argument(
+    arg_parser.add_argument(
         "-d",
         "--display",
         help="Display method.",
         default="Text",
         choices=[i.lower() for i in displays.__all__],
     )
-    parser.add_argument(
+    arg_parser.add_argument(
         "-m",
         "--modes",
-        help="Filter by mode, if supported by extractor.",
+        metavar="MODE",
+        help="Filter by mode, if supported by parser.",
         action="append",
         default=None,
     )
-    parser.add_argument(
+    arg_parser.add_argument(
         "-v",
         "--version",
         action="version",
         help="Show hag version and exit.",
         version=f"%(prog)s {__version__}",
     )
-    args = parser.parse_args()
+    args = arg_parser.parse_args()
 
     if args.list_displays:
         for i in displays.__all__:
             print(i.lower())
-    elif args.list_extractors:
-        for extractor in extractors.__all__:
+    elif args.list_parsers:
+        for parser in parsers.__all__:
             try:
                 # if the install check passes
-                getattr(extractors, extractor)()
-                print(extractor.lower())
+                getattr(parsers, parser)()
+                print(parser.lower())
             except OSError:
                 pass
     else:
-        if args.extractor is None:
-            parser.print_help()
+        if args.parser is None:
+            arg_parser.print_help()
             sys.exit(1)
-        # get the desired extrator and display
-        Extractor = getattr(extractors, args.extractor.title())
+        # get the desired parser and display
+        Parser = getattr(parsers, args.parser.title())
         Display = getattr(displays, args.display.title())
 
         # load hotkeys
-        extractor = Extractor()
-        fetched = extractor.fetch()
-        hotkeys = extractor.extract(fetched)
+        parser = Parser()
+        fetched = parser.fetch()
+        hotkeys = parser.parse(fetched)
         # display
-        Display(hotkeys, has_modes=extractor.has_modes).show(modes=args.modes)
+        Display(hotkeys, has_modes=parser.has_modes).show(modes=args.modes)
 
 
 if __name__ == "__main__":
