@@ -4,7 +4,7 @@ from .sources import Command
 
 
 class Zsh(Parser):
-    required = [Command("zsh")]
+    required = bool(Command("zsh"))
     # TODO: this doesn't work for my setup, my config is not sourced :(
     sources = {"user": [Command("zsh -ci bindkey")]}
     has_modes = False
